summaryrefslogtreecommitdiffstats
path: root/chalk/core/kis_layer.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /chalk/core/kis_layer.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'chalk/core/kis_layer.h')
-rw-r--r--chalk/core/kis_layer.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/chalk/core/kis_layer.h b/chalk/core/kis_layer.h
index 09ecd235..2cff4bc9 100644
--- a/chalk/core/kis_layer.h
+++ b/chalk/core/kis_layer.h
@@ -69,14 +69,14 @@ public:
/**
* Set the entire layer extent dirty; this percolates up to tqparent layers all the
* way to the root layer.
*/
virtual void setDirty(bool propagate = true);
/**
* Add the given rect to the set of dirty rects for this layer;
* this percolates up to tqparent layers all the way to the root
* layer.
*/
virtual void setDirty(const TQRect & rect, bool propagate = true);
@@ -87,41 +87,41 @@ public:
/// Returns the ID of the layer, which is guaranteed to be unique among all KisLayers.
int id() const { return m_id; }
/* Returns the index of the layer in its tqparent's list of child layers. Indices
* increase from 0, which is the topmost layer in the list, to the bottommost.
*/
virtual int index() const;
/// Moves this layer to the specified index within its tqparent's list of child layers.
virtual void setIndex(int index);
/**
* Returns the tqparent layer of a layer. This is 0 only for a root layer; otherwise
* this will be an actual GroupLayer */
- virtual KisGroupLayerSP tqparent() const;
+ virtual KisGroupLayerSP parent() const;
/**
* Returns the previous sibling of this layer in the tqparent's list. This is the layer
* *above* this layer. 0 is returned if there is no tqparent, or if this child has no more
* previous siblings (== firstChild())
*/
virtual KisLayerSP prevSibling() const;
/**
* Returns the next sibling of this layer in the tqparent's list. This is the layer *below*
* this layer. 0 is returned if there is no tqparent, or if this child has no more next
* siblings (== lastChild())
*/
virtual KisLayerSP nextSibling() const;
/**
* Returns the sibling above this layer in its tqparent's list. 0 is returned if there is no tqparent,
* or if this layer is the topmost layer in its group. This is the same as calling prevSibling().
*/
KisLayerSP siblingAbove() const { return prevSibling(); }
/**
* Returns the sibling below this layer in its tqparent's list. 0 is returned if there is no tqparent,
* or if this layer is the bottommost layer in its group. This is the same as calling nextSibling().
*/
KisLayerSP siblingBelow() const { return nextSibling(); }
@@ -197,7 +197,7 @@ public:
KisUndoAdapter *undoAdapter() const;
- /// paints a tqmask where the selection on this layer resides
+ /// paints a mask where the selection on this layer resides
virtual void paintSelection(TQImage &img, TQ_INT32 x, TQ_INT32 y, TQ_INT32 w, TQ_INT32 h);
virtual void paintSelection(TQImage &img, const TQRect& scaledImageRect, const TQSize& scaledImageSize, const TQSize& imageSize);
@@ -69,14 +69,14 @@ public:
/**
- * Set the entire layer extent dirty; this percolates up to tqparent layers all the
+ * Set the entire layer extent dirty; this percolates up to parent layers all the
* way to the root layer.
*/
@@ -69,14 +69,14 @@ public:
/**
* Add the given rect to the set of dirty rects for this layer;
- * this percolates up to tqparent layers all the way to the root
+ * this percolates up to parent layers all the way to the root
* layer.
*/
@@ -87,41 +87,41 @@ public:
/// Returns the ID of the layer, which is guaranteed to be unique among all KisLayers.
int id() const { return m_id; }
- /* Returns the index of the layer in its tqparent's list of child layers. Indices
+ /* Returns the index of the layer in its parent's list of child layers. Indices
* increase from 0, which is the topmost layer in the list, to the bottommost.
*/
@@ -87,41 +87,41 @@ public:
*/
virtual int index() const;
- /// Moves this layer to the specified index within its tqparent's list of child layers.
+ /// Moves this layer to the specified index within its parent's list of child layers.
virtual void setIndex(int index);
/**
@@ -87,41 +87,41 @@ public:
virtual void setIndex(int index);
/**
- * Returns the tqparent layer of a layer. This is 0 only for a root layer; otherwise
+ * Returns the parent layer of a layer. This is 0 only for a root layer; otherwise
* this will be an actual GroupLayer */
@@ -87,41 +87,41 @@ public:
/**
- * Returns the previous sibling of this layer in the tqparent's list. This is the layer
- * *above* this layer. 0 is returned if there is no tqparent, or if this child has no more
+ * Returns the previous sibling of this layer in the parent's list. This is the layer
+ * *above* this layer. 0 is returned if there is no parent, or if this child has no more
* previous siblings (== firstChild())
*/
@@ -87,41 +87,41 @@ public:
virtual KisLayerSP prevSibling() const;
/**
- * Returns the next sibling of this layer in the tqparent's list. This is the layer *below*
- * this layer. 0 is returned if there is no tqparent, or if this child has no more next
+ * Returns the next sibling of this layer in the parent's list. This is the layer *below*
+ * this layer. 0 is returned if there is no parent, or if this child has no more next
* siblings (== lastChild())
*/
@@ -87,41 +87,41 @@ public:
virtual KisLayerSP nextSibling() const;
/**
- * Returns the sibling above this layer in its tqparent's list. 0 is returned if there is no tqparent,
+ * Returns the sibling above this layer in its parent's list. 0 is returned if there is no parent,
* or if this layer is the topmost layer in its group. This is the same as calling prevSibling().
*/
@@ -87,41 +87,41 @@ public:
KisLayerSP siblingAbove() const { return prevSibling(); }
/**
- * Returns the sibling below this layer in its tqparent's list. 0 is returned if there is no tqparent,
+ * Returns the sibling below this layer in its parent's list. 0 is returned if there is no parent,
* or if this layer is the bottommost layer in its group. This is the same as calling nextSibling().
*/